@@ -522,6 +522,8 @@ void initialize(
 	int color_depth;
 	Pixel tmp_pix;
 	int result;
+	int x_negative = 0;
+	int y_negative = 0;
 
 	if (strlen(mainGeometry)) {
 		/* Check the user-specified size */
@@ -538,10 +540,14 @@ void initialize(
 		if (result & HeightValue) {
 			state.total_size.y = SizeHints.height;
 		}
+		if (result & XNegative) 
+			x_negative = 1;
+		if (result & YNegative) 
+			y_negative = 1;
 #ifdef DEBUG
-		printf("User size: %d x %d, position: %d %d\n", 
+		printf("User size: %d x %d position: %d %d (negative %d %d)\n", 
 			state.total_size.x, state.total_size.y,
-			SizeHints.x, SizeHints.y);
+			SizeHints.x, SizeHints.y, x_negative, y_negative);
 #endif
 	}
 	if (state.draw_date) {
@@ -630,7 +636,7 @@ void initialize(
 		x_cleanup();
         }       
 
-        SizeHints.flags= USSize|USPosition|PMinSize|PMaxSize;
+        SizeHints.flags= USSize|USPosition;
         SizeHints.x = 0;
         SizeHints.y = 0;
         XWMGeometry(
@@ -639,7 +645,7 @@ void initialize(
                 mainGeometry,
                 NULL,
                 1,
-                & SizeHints,
+                &SizeHints,
                 &SizeHints.x,
                 &SizeHints.y,
                 &SizeHints.width,
@@ -658,6 +664,13 @@ void initialize(
         SizeHints.min_height =
         SizeHints.max_height =
         SizeHints.height= state.total_size.y;
+        SizeHints.flags |= PMinSize|PMaxSize;
+
+	/* Correct the offsets if the X/Y are negative */
+	if (x_negative)
+		SizeHints.x -= state.total_size.x;
+	if (y_negative)
+		SizeHints.y -= state.total_size.y;
 
         backgroundWindow = XCreatePixmap(
                 mainDisplay,
@@ -709,6 +722,11 @@ void initialize(
                 mainWindow,     /* window */
                 & winAttr       /* window_attributes_return */
                 );
+#ifdef DEBUG
+	printf("Window Attributes: %d x %d at %d %d border %d\n",
+		winAttr.width, winAttr.height, winAttr.x, winAttr.y,
+		winAttr.border_width);
+#endif
                 
         status = XStringListToTextProperty(&app_name, 1, &title);
         XSetWMName(mainDisplay, mainWindow, &title);
